@@ -1,9 +1,9 @@
 package WordList;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-22'; # DATE
+our $DATE = '2020-05-23'; # DATE
 our $DIST = 'WordList'; # DIST
-our $VERSION = '0.7.0'; # VERSION
+our $VERSION = '0.7.1'; # VERSION
 
 use strict 'subs', 'vars';
 
@@ -43,7 +43,7 @@ sub new {
 sub each_word {
     my ($self, $code) = @_;
 
-    my $class = ref($self);
+    my $class = $self->{orig_class} || ref($self);
 
     my $fh = \*{"$class\::DATA"};
 
@@ -58,7 +58,7 @@ sub each_word {
 sub next_word {
     my $self = shift;
 
-    my $class = ref($self);
+    my $class = $self->{orig_class} || ref($self);
     my $fh = \*{"$class\::DATA"};
     my $word = <$fh>;
     chomp $word if defined $word;
@@ -68,7 +68,7 @@ sub next_word {
 sub reset_iterator {
     my $self = shift;
 
-    my $class = ref($self);
+    my $class = $self->{orig_class} || ref($self);
     my $fh = \*{"$class\::DATA"};
     seek $fh, ${"$class\::DATA_POS"}, 0;
 }
@@ -159,7 +159,7 @@ WordList - Word lists
 
 =head1 VERSION
 
-This document describes version 0.7.0 of WordList (from Perl distribution WordList), released on 2020-05-22.
+This document describes version 0.7.1 of WordList (from Perl distribution WordList), released on 2020-05-23.
 
 =head1 SYNOPSIS
 
@@ -279,7 +279,12 @@ L</next_word>.
 
 Usage:
 
- $wl->pick([ $n , [ $allow_duplicates ] ]) => list
+ @words = $wl->pick([ $num=1 [ , $allow_duplicates=0 ] ])
+
+Examples:
+
+ ($word) = $wl->pick;
+ @words  = $wl->pick(3);
 
 Pick C<$n> (default: 1) random word(s) from the list, without duplicates (unless
 C<$allow_duplicates> is set to true). If there are less then C<$n> words in the
@@ -311,6 +316,21 @@ Return all the words in a list, in order. Note that if wordlist is very large
 you might want to use L</"each_word"> instead to avoid slurping all words into
 memory.
 
+=head1 FAQ
+
+=head2 Why does pick() return "1"?
+
+You probably write this:
+
+ $word = $wl->pick;
+
+instead of this:
+
+ ($word) = $wl->pick;
+
+C<pick()> returns a list and in scalar context it returns the number of elements
+in the list which is 1. This is a common context trap in Perl.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/WordList>.
@@ -331,8 +351,6 @@ feature.
 
 C<WordListRole::*> modules.
 
-C<WordListMod::*> modules.
-
 C<WordList::*> modules.
 
 L<Rinci>.
